@@ -28,7 +28,7 @@ dependencies using raw pip. The virtual environment is not created, but one can
 issue `python3 -m venv venv/ && . venv/bin/activate` to create one.
 """
 
-__version__ = "1.4.3"
+__version__ = "1.4.5"
 __author__ = "Fridolin Pokorny <fridex.devel@gmail.com>"
 __title__ = "micropipenv"
 
@@ -48,7 +48,7 @@ from pathlib import Path
 from urllib.parse import urlparse
 
 _LOGGER = logging.getLogger(__title__)
-_SUPPORTED_PIP_STR = ">=9,<=22.2.2"  # Respects requirement in setup.py and latest pip to release date.
+_SUPPORTED_PIP_STR = ">=9,<=22.3.1"  # Respects requirement in setup.py and latest pip to release date.
 
 try:
     from pip import __version__ as pip_version
@@ -302,6 +302,15 @@ def _compute_poetry_hash(pyproject):  # type: (MutableMapping[str, Any]) -> str
     relevant_keys = ["dependencies", "dev-dependencies", "source", "extras"]
     relevant_content = {key: poetry_data.get(key) for key in relevant_keys}
 
+    # relevant_keys are the original one and they should always be in
+    # the relevant_content even their value is None.
+    # group is a new key since poetry 1.2 and we should include it only
+    # if pyproject.toml contains it. Including it always would break
+    # backward compatibility.
+    # See: https://github.com/python-poetry/poetry/blob/4a07b5e0243bb8879dd6725cb901d9fa0f6eb182/src/poetry/packages/locker.py#L278-L293
+    if "group" in poetry_data:
+        relevant_content["group"] = poetry_data.get("group")
+
     return hashlib.sha256(json.dumps(relevant_content, sort_keys=True).encode()).hexdigest()
 
 
@@ -792,7 +801,11 @@ def _poetry2pipfile_lock(
             raise PoetryError(message)
 
         hashes = []
-        for file_entry in poetry_lock["metadata"]["files"][entry["name"]]:
+        # Older poetry.lock format contains files in [metadata].
+        # New version 2.0 has files in [[package]] section.
+        metadata_file_entries = poetry_lock["metadata"].get("files", {}).get(entry["name"], [])
+        package_file_entries = entry.get("files", [])
+        for file_entry in metadata_file_entries + package_file_entries:
             hashes.append(file_entry["hash"])
 
         requirement: Dict[str, Any] = {"version": "=={}".format(entry["version"])}
